
% This file "creates" a vector Y and a variance-covariance matrix Sigma.
% Then, given the index of the variable of interest, the "type" of the
% confidence interval, the nominal level, a vector of indicator variables
% indicating whether the corresponding entry in Y is bounded, and a vector
% of bounds, this file calls the function SSCI to compute our Short and 
% Simple Confidence Interval (SSCI). It also computes the corresponding 
% standard confidence interval (SCI).

clc;
clear;

% Vector of coefficient estimates
Y = [0;-0.3;-0.1]

% Variance covariance matrix (estimate)
cov12 = 0.5;
cov13 = 0.5;
cov23 = 0.5;

Sigma = [1 cov12 cov13;cov12 1 cov23;cov13 cov23 1]

% index of the variable of interest
index = 1;

% type of CI: upper one-sided (1), two-sided (0), or lower one-sided (-1)
type = 0;  

% Nominal level - possible values are 0.01, 0.05, and 0.1
alpha = 0.05;

% Vector indicating if parameter is bounded from below (1), unbounded (0),
% or bounded from above (-1)
bounded = [1;1;1];

% Vector of bounds
bounds = [0;0;0];

% Our short and simple confidence interval - Note that alpha, bounded, and 
% bounds are optional input arguments
SSCI = SSCI(Y,Sigma,index,type,alpha,bounded,bounds)

% The standard confidence interval
if type == 1
    SCI = [Y(index)-norminv(1-alpha)*sqrt(Sigma(index,index)),Inf]
elseif type == -1
    SCI = [-Inf,Y(index)+norminv(1-alpha)*sqrt(Sigma(index,index))]
elseif type == 0
    SCI = [Y(index)-norminv(1-alpha/2)*sqrt(Sigma(index,index)),...
        Y(index)+norminv(1-alpha/2)*sqrt(Sigma(index,index))]
end
